@@ -26,18 +26,19 @@ from disclosure_extractor.judicial_watch_utils import (
     get_text_fields,
     process_addendum,
 )
+from disclosure_extractor.post_processing import _fine_tune_results
 
 
 def print_results(results):
     """Display the extraction in a nice table printout."""
     cd = {}
     for k, v in results["sections"].items():
-        columns = results["sections"][k]["columns"]
+        columns = results["sections"][k]["fields"]
         cd[k] = []
         max_lengths = [len(x) for x in columns]
         if v["rows"] != {}:
             x = cd[k]
-            for _, row in v["rows"].items():
+            for row in v["rows"]:
                 if len(row.items()) != len(columns):
                     continue
                 r = []
@@ -164,26 +165,35 @@ def process_financial_document(
     pages = convert_from_bytes(pdf_bytes)
     page_total = len(pages)
     logging.info("Document is %s pages long" % page_total)
-
     logging.info("Determining document structure")
+
     try:
-        document_structure, check_count = extract_contours_from_page(pages)
+        document_structure, check_count = extract_contours_from_page(
+            pages, resize=True
+        )
     except:
         return {"success": False, "msg": CheckboxesNotFound}
 
     if check_count < 8:
         logging.warning("Failed to extract document structure")
-        return {"success": False, "msg": "Failed to process document properly"}
+        return {
+            "success": False,
+            "msg": "Failed to process document properly",
+            "checkbox_count_found": check_count,
+        }
 
     logging.info("Extracting content from financial disclosure")
-    results = process_document(document_structure, pages, show_logs)
+    results = process_document(
+        document_structure, pages, show_logs, resize=True
+    )
     results["page_count"] = page_total
     results["pdf_size"] = len(pdf_bytes)
-
     results["wealth"] = estimate_investment_net_worth(results)
-
     results["success"] = True
-    return results
+
+    # Cleanup raw data & update document structure
+    cleaned_data = _fine_tune_results(results)
+    return cleaned_data
 
 
 def process_judicial_watch(
@@ -236,6 +246,13 @@ def process_judicial_watch(
 
     # Calculate net worth and mark processing as a success
     results["wealth"] = estimate_investment_net_worth(results)
+
+    # Add final data
+    results["page_count"] = page_total
+    results["pdf_size"] = len(pdf_bytes)
     results["success"] = True
 
-    return results
+    # Cleanup raw data & update document structure
+    cleaned_data = _fine_tune_results(results)
+
+    return cleaned_data
