@@ -43,7 +43,7 @@ def erode(image, q):
     return cv2.erode(image, kernel, iterations=1)
 
 
-def extract_contours_from_page(pages):
+def extract_contours_from_page(pages, resize):
     """Process PDF
 
     Return the document structure as JSON data to easily and accurately
@@ -59,7 +59,8 @@ def extract_contours_from_page(pages):
     s7 = []
     little_checkboxes = []
     for page_image in pages:
-        page_image = page_image.resize((1653, 2180))
+        if resize:
+            page_image = page_image.resize((1653, 2180))
         mode = cv2.RETR_CCOMP
         method = cv2.CHAIN_APPROX_SIMPLE
         cv_image = np.array(page_image)
@@ -94,7 +95,7 @@ def extract_contours_from_page(pages):
                         / 3
                     )
                     is_empty = False
-                    if mean < 230:
+                    if mean < 215:
                         is_empty = True
 
                     for k, sect in results["sections"].items():
@@ -269,8 +270,6 @@ def extract_contours_from_page(pages):
     for grouping in investment_group:
         col_indx = 0
         groups = list(grouping[1])
-        sect = groups[0]["section"]
-        # print(sect)
         results["sections"]["Investments and Trusts"]["rows"][row_index] = {}
         for group in sorted(groups, key=lambda x: x["x"]):
             group["coords"] = (
@@ -279,7 +278,7 @@ def extract_contours_from_page(pages):
                 (group["x"] + group["w"]),
                 (group["y"] + group["h"]),
             )
-            column = results["sections"]["Investments and Trusts"]["columns"][
+            column = results["sections"]["Investments and Trusts"]["fields"][
                 col_indx
             ]
             results["sections"]["Investments and Trusts"]["rows"][row_index][
@@ -299,6 +298,10 @@ def extract_contours_from_page(pages):
         if results["sections"][sect]["rows"] == {}:
             row_index = 0
         results["sections"][sect]["rows"][row_index] = {}
+        if len(groups) != len(results["sections"][sect]["fields"]):
+            continue
+        if sorted(groups, key=lambda x: x["x"])[0]["x"] > 120:
+            continue
         for group in sorted(groups, key=lambda x: x["x"]):
             group["coords"] = (
                 group["x"],
@@ -306,9 +309,10 @@ def extract_contours_from_page(pages):
                 (group["x"] + group["w"]),
                 (group["y"] + group["h"]),
             )
-            # print(results["sections"][sect]["columns"], col_indx)
+            # print(results["sections"][sect]["fields"], col_indx)
+
             try:
-                column = results["sections"][sect]["columns"][col_indx]
+                column = results["sections"][sect]["fields"][col_indx]
                 results["sections"][sect]["rows"][row_index][column] = group
                 results["sections"][sect]["empty"] = check[sect]
                 col_indx += 1
